@@ -5,7 +5,6 @@ from importlib import import_module
 from logging import getLogger
 from typing import Any, Callable, Dict, List, Optional, Set, Union
 
-import cloudpickle
 import luigi
 import pandas as pd
 
@@ -43,14 +42,6 @@ class TaskOnKart(luigi.Task):
                                                   description='If this is true, this task will not run only if all input and output files exist,'
                                                   ' and all input files are modified before output file are modified.',
                                                   significant=False)
-    serialized_task_definition_check = luigi.BoolParameter(default=False,
-                                                           description='If this is true, this task will not run only if all input and output files exist,'
-                                                           ' and this task class is modified.',
-                                                           significant=False)
-    ignore_serializing_task_definition_error = luigi.BoolParameter(default=False,
-                                                                   description='if this is true, this task ignores error while serializing this task.'
-                                                                   ' This parameter is effective only when `serialized_task_check` is `True`',
-                                                                   significant=False)
     delete_unnecessary_output_files = luigi.BoolParameter(default=False, description='If this is true, delete unnecessary output files.', significant=False)
     significant = luigi.BoolParameter(default=True,
                                       description='If this is false, this task is not treated as a part of dependent tasks for the unique id.',
@@ -66,6 +57,11 @@ class TaskOnKart(luigi.Task):
         description='True for failing the task immediately when the cache is locked, instead of waiting for the lock to be released',
         significant=False)
     fail_on_empty_dump: bool = ExplicitBoolParameter(default=False, description='Fail when task dumps empty DF', significant=False)
+    store_index_in_feather: bool = ExplicitBoolParameter(default=True,
+                                                         description='Wether to store index when using feather as a output object.',
+                                                         significant=False)
+
+    cache_unique_id: bool = ExplicitBoolParameter(default=True, description='Cache unique id during runtime', significant=False)
 
     def __init__(self, *args, **kwargs):
         self._add_configuration(kwargs, 'TaskOnKart')
@@ -135,17 +131,15 @@ class TaskOnKart(luigi.Task):
         return input_modification_time <= output_modification_time
 
     def clone(self, cls=None, **kwargs):
+        _SPECIAL_PARAMS = {'rerun', 'strict_check', 'modification_time_check'}
         if cls is None:
             cls = self.__class__
 
         new_k = {}
         for param_name, param_class in cls.get_params():
-            if param_name in {'rerun', 'strict_check', 'modification_time_check'}:
-                continue
-
             if param_name in kwargs:
                 new_k[param_name] = kwargs[param_name]
-            elif hasattr(self, param_name):
+            elif hasattr(self, param_name) and (param_name not in _SPECIAL_PARAMS):
                 new_k[param_name] = getattr(self, param_name)
 
         return cls(**new_k)
@@ -162,7 +156,11 @@ class TaskOnKart(luigi.Task):
                                          redis_port=self.redis_port,
                                          redis_timeout=self.redis_timeout,
                                          redis_fail_on_collision=self.redis_fail_on_collision)
-        return gokart.target.make_target(file_path=file_path, unique_id=unique_id, processor=processor, redis_params=redis_params)
+        return gokart.target.make_target(file_path=file_path,
+                                         unique_id=unique_id,
+                                         processor=processor,
+                                         redis_params=redis_params,
+                                         store_index_in_feather=self.store_index_in_feather)
 
     def make_large_data_frame_target(self, relative_file_path: str = None, use_unique_id: bool = True, max_byte=int(2**26)) -> TargetOnKart:
         formatted_relative_file_path = relative_file_path if relative_file_path is not None else os.path.join(self.__module__.replace(".", "/"),
@@ -268,8 +266,10 @@ class TaskOnKart(luigi.Task):
         self._get_output_target(target).dump(obj, lock_at_dump=self._lock_at_dump)
 
     def make_unique_id(self):
-        self.task_unique_id = self.task_unique_id or self._make_hash_id()
-        return self.task_unique_id
+        unique_id = self.task_unique_id or self._make_hash_id()
+        if self.cache_unique_id:
+            self.task_unique_id = unique_id
+        return unique_id
 
     def _make_hash_id(self):
         def _to_str_params(task):
@@ -281,16 +281,6 @@ class TaskOnKart(luigi.Task):
         dependencies = [d for d in dependencies if d is not None]
         dependencies.append(self.to_str_params(only_significant=True))
         dependencies.append(self.__class__.__name__)
-        if self.serialized_task_definition_check:
-            try:
-                dependencies.append(str(cloudpickle.dumps(self.__class__)))
-            except Exception as err:
-                if not self.ignore_serializing_task_definition_error:
-                    msg = f'{self.__class__.__name__} is not serializable,' \
-                          ' you can ignore this error by setting `ignore_serializing_task_error` to `True`'
-                    raise TypeError(msg) from err
-                logger.warning(f'{self.__class__.__name__} is not serializable, so modification cannot be detected')
-
         return hashlib.md5(str(dependencies).encode()).hexdigest()
 
     def _get_input_targets(self, target: Union[None, str, TargetOnKart]) -> Union[TargetOnKart, List[TargetOnKart]]:
